<?php

namespace Drupal\micro_sso;

/**
 * Middleware for the micro_site module.
 */
interface MicroSsoHelperInterface {

  /**
   * The request is done on the master host.
   *
   * @return boolean
   */
  public function isMaster();

  /**
   * Get a valid HTTP Origin header if it matches an existing site.
   *
   * @return string|Null
   *   The existing site url if found, else Null.
   */
  public function getOrigin();

  /**
   * Write token.
   *
   * @param string $origin
   *   The http origin base url.
   * @param string $destination
   *   The destination query parameter.
   *
   * @return string
   *   Valid URL for login into the site.
   */
  function writeToken($origin, $destination = null);

  /**
   * Get default URL scheme.
   */
  function getScheme();

  /**
   * Get the current request.
   *
   * @return \Symfony\Component\HttpFoundation\Request
   *   The request oject.
   */
  public function getRequest();

  /**
   * Get the Request Time.
   *
   * @return string
   *   The request time timestamp.
   */
  public function getRequestTime();

  /**
   * Get the current user
   *
   * @return \Drupal\Core\Session\AccountInterface
   *   The current user object.
   */
  public function getCurrentUser();

  /**
   * The current user is authenticated ?
   *
   * @return boolean
   *   TRUE if the current user is authenticated.
   */
  public function userIsAuthenticated();

  /**
   * Get the sso cache backend object.
   *
   * @return \Drupal\Core\Cache\CacheBackendInterface
   */
  public function getCacheSso();


}
